@@ -168,19 +168,40 @@ def excitonic_bilayer(gap=0.0,g=None,**kwargs):
     gc = gc + np.array([0.,0.,1]) # conduction
     g = gv + gc # add geometries
     def tij(r1,r2):
-      dr = r1 - r2
-      dr2 = dr.dot(dr)
-      if 0.99<dr2<1.01: return np.sign(r1[2])
-      return 0.0
+        dr = r1 - r2
+        dr2 = dr.dot(dr)
+        if 0.99<dr2<1.01: return np.sign(r1[2])
+        return 0.0
     h = g.get_hamiltonian(tij=tij,has_spin=False) # no spin
     def fons(r):
-      if r[2]>0.0: return -fermiv - gap/2.
-      else: return fermiv + gap/2
+        if r[2]>0.0: return -fermiv - gap/2.
+        else: return fermiv + gap/2
     h.add_onsite(fons)
     return h
 
 
 
+def FeSe():
+    """Return the Hamiltonian of FeSe, a bandstructure
+    displaying two pockets"""
+    g = geometry.cubic_lattice() # cubic lattice
+    g = g.supercell([1,1,2]) # create a bilayer
+    g.dimensionality = 2 # set as 2d
+    g.center()
+    def fh(r1,r2): # function for the hoppings
+        dr = r1-r2
+        dr2 = dr.dot(dr)
+        if 0.9<dr2<1.1:
+            if abs(dr[2])>0.1: return 0. # no hopping
+            if np.sign(r1[2]+r2[2])>0: return 1.0 # return hopping
+            else: return -1.0 
+        return 0.
+    h = g.get_hamiltonian(tij=fh)
+    h.add_onsite(lambda r: 3.+1*r[2])
+    return h
+
+
+
 
 
 
